@@ -29,6 +29,7 @@
 // KF
 #include <KAboutData>
 #include <KCrash>
+#include <KDBusService>
 #include <KLocalizedString>
 // Qt
 #include <QApplication>
@@ -49,7 +50,8 @@ int main(int argc, char *argv[])
 
     QApplication app(argc, argv);
 
-    KLocalizedString::setApplicationDomain("kfourinline");
+    KLocalizedString::setApplicationDomain(QByteArrayLiteral("kfourinline"));
+
     KAboutData aboutData(QStringLiteral("kfourinline"),
                          i18n("KFourInLine"),
                          QStringLiteral(KFOURINLINE_VERSION_STRING),
@@ -94,6 +96,8 @@ int main(int argc, char *argv[])
         qCDebug(KFOURINLINE_LOG) << "Running in demo mode" << global_demo_mode;
     }
 
+    KDBusService service;
+
     // Start application
     // Start session
     if (app.isSessionRestored()) {
